#ifndef EAVESDROPPER_DORMANTNODEVIEW_H
#define EAVESDROPPER_DORMANTNODEVIEW_H

// ***************************************************************************
// System Includes
// ***************************************************************************

#include <be/media/MediaAddOn.h>
#include <be/media/MediaNode.h>

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.
#include "AbstractNodeView.h"

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Type Definitions
// ***************************************************************************

// ***************************************************************************
// Class Definition
// ***************************************************************************

/**
 * The DormantNodeView class represents a dormant media node.
 */
class DormantNodeView : public AbstractNodeView
{
public:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

	/**
	 * Constructor.
	 *
	 * @param infoWindow Pointer to the Information window.
	 * @param dormantNodeInfo The dormant_node_info structure that describes
	 *        this media node.
	 */
	DormantNodeView(InfoWindow* infoWindow,
		dormant_node_info dormantNodeInfo);

	/** Automatically generated copy constructor. */
	// LiveDormantNodeView(const DormantNodeView& old);

	/** Destructor. */
	virtual ~DormantNodeView(void);

	/** Automatically generated assignment operator. */
	// DormantNodeView& operator=(DormantNodeView& right);

	/** Draws the view. */
	virtual void Draw(BRect updateRect);

	/** Returns the dormant_node_info structure that describes this node. */
	dormant_node_info GetDormantNodeInfo(void);
	
	/** Returns the dormant_flavor_info structure for this node. */
	dormant_flavor_info GetDormantFlavorInfo(void);

	/**
	 * Returns the list of media_file_format structures that describe the
	 * file formats that this node can read.
	 */
	BList* GetInputFileFormats(void);

	/**
	 * Returns the list of media_file_format structures that describe the
	 * file formats that this node can write.
	 */
	BList* GetOutputFileFormats(void);

protected:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

private:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	/** The dormant_node_info structure that describes this media node. */
	dormant_node_info dormantNodeInfo;
	
	/** The dormant_flavor_info structure for this node. */
	dormant_flavor_info dormantFlavorInfo;

	/** The media_file_format structures that this node can read. */
	BList* inputFileFormats;
	
	/** The media_file_format structures that this node can write. */
	BList* outputFileFormats;

	// Member Function Definitions ===========================================

	/**
	 * Queries the Media Server for all interesting information on this node,
	 * and caches this information for future reference.
	 */	
	void GetNodeInfo(void);
};

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

#endif // EAVESDROPPER_DORMANTNODEVIEW_H
