// ***************************************************************************
// Implementation System Includes
// ***************************************************************************

// ***************************************************************************
// Implementation Project Includes
// ***************************************************************************

#include "EavesdropperMain.h"
#include "LiveNodesView.h"
#include "LiveNodeView.h"
#include "Connection.h"
#include "ConnectorView.h"

// ***************************************************************************
// Implementation Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Type Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Variable Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Variable Definitions
// ***************************************************************************

// ***************************************************************************
// PUBLIC Member Function Definitions
// ***************************************************************************

// ===========================================================================
// Constructor
// ===========================================================================

LiveNodesView::LiveNodesView(BRect frame)
	: BView(frame,
		"LivesNodesView",
		B_FOLLOW_ALL_SIDES,
		B_WILL_DRAW)
{
	SetViewColor(COLOR_BACKGROUND);
}

// ===========================================================================
// MessageReceived
// ===========================================================================

void
LiveNodesView::MessageReceived(BMessage* message)
{
	// Figure out what kind of message was received.
	switch(message->what)
	{
		// The user dragged a node and dropped it on us.
		case MSG_DRAG_NODE:
		{
			if (message->WasDropped())
			{
				void* view;
				if (message->FindPointer("LiveNodeView", &view) == B_OK)
				{
					BPoint offset;
					if (message->FindPoint("Offset", &offset) == B_OK)
					{
						BPoint dropPoint = 
							ConvertFromScreen(message->DropPoint());

						// Correct drop point for the point where the mouse
						// was clicked inside the node view, and the amount
						// that the lives nodes view has been scrolled.
						dropPoint.x -= offset.x + LeftTop().x;
						dropPoint.y -= offset.y + LeftTop().y;
						
						((LiveNodeView*) view)->MoveTo(dropPoint);
	
						RedrawConnections();
					}
				}
			}
			break;
		}
	
		// Let the original BView handle the message.
		default:
		{
			BView::MessageReceived(message);
			break;
		}
	}
}

// ===========================================================================
// Draw
// ===========================================================================

void 
LiveNodesView::Draw(BRect updateRect)
{
	BView::Draw(updateRect);
	RedrawConnections();
}

// ===========================================================================
// ScrollTo
// ===========================================================================

void
LiveNodesView::ScrollTo(BPoint point)
{
	BView::ScrollTo(point);
	RedrawConnections();
}

// ===========================================================================
// RedrawConnections
// ===========================================================================

void 
LiveNodesView::RedrawConnections(void)
{
	// Tell all the connections to draw themselves into us.
	if (connections != 0)
	{
		for (int32 t=0; t<connections->CountItems(); ++t)
		{
			Connection* connection = (Connection*) connections->ItemAt(t);
			connection->Draw(this);
		}
	}
}

// ===========================================================================
// SetConnections
// ===========================================================================

void
LiveNodesView::SetConnections(BList* connections)
{
	this->connections = connections;
}
	
// ***************************************************************************
// PROTECTED Member Function Definitions
// ***************************************************************************

// ***************************************************************************
// PRIVATE Member Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Definitions
// ***************************************************************************

// ***************************************************************************
// Global Function Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Function Definitions
// ***************************************************************************
