#ifndef EAVESDROPPER_MAINWINDOW_H
#define EAVESDROPPER_MAINWINDOW_H

// ***************************************************************************
// System Includes
// ***************************************************************************

#include <be/interface/Window.h>
#include <be/media/MediaRoster.h>
#include <be/support/List.h>

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.

#include "DormantNodesView.h"
#include "LiveNodesView.h"

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

class InfoWindow;

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Type Definitions
// ***************************************************************************

// ***************************************************************************
// Class Definition
// ***************************************************************************

/**  
 * The MainWindow class is Eavesdropper's main window.
 */
class MainWindow : public BWindow
{
public:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================
 
	/**
	 * Constructor.
	 *
	 * @param mediaRoster Pointer to the Media Roster.
	 * @param infoWindow Pointer to the Information window.
	 */
	MainWindow(BMediaRoster* mediaRoster, InfoWindow* infoWindow); 

	/** Automatically generated copy constructor. */
	// MainWindow(const MainWindow& old);

	/** Destructor. */
	virtual ~MainWindow(void);

	/** Automatically generated assignment operator. */
	// MainWindow& operator=(MainWindow& right);

	/** Quits the entire application. */
	virtual bool QuitRequested(void);

	/** Handles the messages that the window receives. */
	virtual void MessageReceived(BMessage* message);

	/** Responds to a notification that the window has moved. */
	virtual void FrameMoved(BPoint screenPoint);
	
	/** Responds to a notification that the window has been resized. */
	virtual void FrameResized(float width, float height);

protected:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

private:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	/** Pointer to the Media Roster. */
	BMediaRoster* mediaRoster;

	/** Pointer to the Information window. */
	InfoWindow* infoWindow;

	/** Pointer to the view that contains the views of the live nodes. */
	LiveNodesView* liveNodesView;

	/** The list of current live node views. */
	BList* liveNodes;

	/** The list of the connections between the live nodes. */
	BList* connections;

	/** Pointer to the view that contains the views of the dormant nodes. */
	DormantNodesView* dormantNodesView;
	
	/** The list of dormant node views. */
	BList* dormantNodes;
	
	// Member Function Definitions ===========================================

	/** Saves the window's frame into the settings file. */	
	void SaveSettings(void);
	
	/**
	 * Creates LiveNodeView objects for all the live nodes and adds them to
	 * the live nodes view.
	 */
	void Refresh(void);

	/**
	 * Automatically places the views of the live nodes in a sort-of smart
	 * order.
	 */
	void CleanUp(void);
	
	/** Frees the node and connection objects. */
	void GetRidOfStuff(void);
};

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

#endif // EAVESDROPPER_MAINWINDOW_H
